@@ -108,7 +108,7 @@ def processIndex(table, index, idxNameFunc=uuid.uuid4, indexExists=True, join=Tr
     if index.name != "" and index.name != None:
         parts.append(index.name)
     else:
-        parts.append(''.join(str(idxNameFunc()).split('-')))
+        parts.append('_' + ''.join(str(idxNameFunc()).split('-')))
     parts.append(f' ON {table.name} (')
     for i, col in enumerate(index.subjects):
         parts.append(col.name)
@@ -261,7 +261,7 @@ def coerceColType(colType):
     texts = ('STR', 'DATE', 'DATETIME', 'TIMESTAMP', 'TIME', 'VARCHAR', 'TINYTEXT', 'SMALLTEXT', 'MEDIUMTEXT', 'LONGTEXT')
     if colType in texts:
         return 'TEXT'
-    blobs = ('TINYBLOB', 'SMALLBLOB', 'MEDIUMBLOB', 'LONGBLOB', 'BYTE', 'BYTES')
+    blobs = ('TINYBLOB', 'SMALLBLOB', 'MEDIUMBLOB', 'LONGBLOB', 'BYTE', 'BYTES', 'UUID')
     if colType in blobs:
         return 'BLOB'
     res = re.search(r'VARCHAR\([0-9]+\)', colType)
